// SkinButton.cpp : implementation file	
//

#include "stdafx.h"
#include "MenuBarApp.h"
#include "MenuButton.h"


// CSkinButton

IMPLEMENT_DYNAMIC(CMenuButton, CButton)

CMenuButton::CMenuButton(CString strText,CFont* pFont,COLORINDEX* clrIndex,UINT nCount)
{
	
	m_dwStyle = DT_SINGLELINE | DT_CENTER | DT_NOCLIP ; 

	CDC* pDC = GetDesktopWindow()->GetDC() ; 
	CFont* oldFont ;

	if (pFont != NULL) 
		oldFont = pDC->SelectObject(pFont) ;  

	SetRect(&m_rcSize,0,0,0,0) ; 
	pDC->DrawText(strText,-1,&m_rcSize,DT_CALCRECT | m_dwStyle) ;

	 m_rcSize.right += 15;
		
	this->strText = strText ; 
	LOGFONT lg ; 
	
	pFont->GetLogFont(&lg) ; 
	fontText.CreateFontIndirectW(&lg) ; 

	for (int i =0 ; i < nCount;i++) 
	{
		COLORINDEX index = clrIndex[i] ; 
		switch (index.nID) 
		{
			case CLR_TEXT :  clrText = index.clr ; break ; 
			case CLR_INTERIOR : clrBkg = index.clr ; break ; 
			case CLR_HILITE: clrHiLite = index.clr ; break ;
			case CLR_FRAME: cltBorder = index.clr ; break ;  
			case CLR_TEXT_DISABLED: clrTxtDisable = index.clr ;break ; 
			case CLR_DISABLED: clrItemDisable = index.clr ; break ;

		}
	}

}

CMenuButton::~CMenuButton()
{
	fontText.DeleteObject() ;

}
void CMenuButton::OnMouseMove(UINT nFlags,CPoint point) 
{

	m_bMouseOver = TRUE ; 

	CRect rc; 
	GetWindowRect(&rc) ;

	if (IsWindowEnabled()) 	
		m_skinMenu->TrackPopupMenu(TPM_TOPALIGN |TPM_LEFTBUTTON|TPM_RIGHTBUTTON ,rc.left,rc.bottom,this) ; 

	Invalidate(FALSE) ; 

	CButton::OnMouseMove(nFlags, point);
}
void CMenuButton::OnLButtonDown(UINT nFlags,CPoint point) 
{
	
	SetCapture() ; 
	Invalidate(FALSE) ; 


	m_bMouseDown = TRUE ; 
	m_bMouseUp = FALSE ; 
    
	CButton::OnLButtonDown(nFlags, point);
}

void CMenuButton::OnLButtonUp(UINT nFlags,CPoint point) 
{
	m_bMouseUp = TRUE ; 
	m_bMouseDown = FALSE ; 

	HRGN hRgn = CreateRectRgn(0,0,0,0); 
	GetWindowRgn(hRgn) ; 
		
	if (PtInRegion(hRgn,point.x,point.y))
	{
		int nCtrlID = GetDlgCtrlID() ; 
		
		::SendMessage(GetParent()->m_hWnd,WM_COMMAND,
						MAKEWPARAM(nCtrlID,BN_CLICKED),(LPARAM)m_hWnd);
	}
		
	
	DeleteObject(hRgn) ; 
	ReleaseCapture() ;

	Invalidate() ; 
		
	
	CButton::OnLButtonUp(nFlags, point);
}

void CMenuButton::PreSubclassWindow()
{
	
	ModifyStyle(0,BS_OWNERDRAW) ;
	CButton::PreSubclassWindow() ; 

}
void CMenuButton::OnTimer(UINT_PTR nIDEvent) 
{
	CPoint p (GetMessagePos()) ;
	GetCursorPos(&p) ; 
 	
	CRect rc ; 
	GetWindowRect(&rc) ; 

	POINT ps ; 
	ps.x = p.x; ps.y = p.y ; 

	if (!PtInRect(&rc,ps) )
	{
		m_bMouseOver = FALSE ; 
		m_bMouseDown = FALSE ; 
		m_bMouseUp = FALSE ; 
			
	}
	else 
	{	
		m_bMouseOver = TRUE ; 
		SetFocus() ; 
	
	}
	Invalidate(FALSE) ; 
	

	CButton::OnTimer(nIDEvent);
}
void CMenuButton::OnKillFocus(CWnd* pNewWnd) 
{
	if (pNewWnd) 
		Click(pNewWnd) ; 
}

void CMenuButton::DrawItem( LPDRAWITEMSTRUCT lpDrawItemStruct )
{
	UINT nItemID = lpDrawItemStruct->itemID ; 


	CRect rc = lpDrawItemStruct->rcItem ; 

	CDC* pDC = CDC::FromHandle(lpDrawItemStruct->hDC) ; 
	CFont* oldFont ; 

	if (fontText.GetSafeHandle() != NULL) 
		oldFont = pDC->SelectObject(&fontText) ;  

	CRect rcText ;SetRect(&rcText,0,0,0,0) ; 
	pDC->DrawText(strText,-1,&rcText,m_dwStyle | DT_CALCRECT) ;

	if (IsWindowEnabled()) 
	{
	
		if (m_bMouseOver) 
		{
			pDC->FillSolidRect(&rc,clrHiLite) ; 
			pDC->SetTextColor(clrText) ;  

			CBrush brush (cltBorder); 
			pDC->FrameRect(&rc,&brush);
			pDC->SetBkMode(TRANSPARENT) ; 
			pDC->DrawText(strText,-1,&rc,m_dwStyle) ; 
		} 
		else 
		{
			pDC->FillSolidRect(&rc,clrBkg) ; 
			pDC->SetTextColor(clrText) ; 
			pDC->SetBkMode(TRANSPARENT) ; 
			pDC->DrawText(strText,-1,&rc,m_dwStyle) ; 

		}

	}
	else 
	{
		pDC->FillSolidRect(&rc,clrBkg) ; 
		pDC->SetTextColor(clrTxtDisable) ; 
		pDC->SetBkMode(TRANSPARENT) ; 
	    pDC->DrawText(strText,-1,&rc,m_dwStyle) ; 

	}


}

void CMenuButton::MeasureItem(LPMEASUREITEMSTRUCT lpMeasureItemStruct)
{
	
	UINT nID = lpMeasureItemStruct->itemID ;  
		
}

void CMenuButton::Click (CWnd* pWindow) 
{
	
	RECT windowRect;
	::GetWindowRect(pWindow->m_hWnd,&windowRect);
	MOUSEINPUT miDown = { windowRect.left , windowRect.top  ,
	0, MOUSEEVENTF_LEFTDOWN, 0, 0 };
	
	INPUT inDown;
	inDown.type = INPUT_MOUSE;
	inDown.mi = miDown;
	MOUSEINPUT miUp = { windowRect.left , windowRect.top  ,
	0, MOUSEEVENTF_LEFTUP, 0, 0 };
	
	INPUT inUp;
	inUp.type = INPUT_MOUSE;
	inUp.mi = miUp;
	
	INPUT inputs[2];
	inputs[0] = inDown;
	inputs[1] = inUp;
	
	SendInput(2,inputs,sizeof inUp);

}
BEGIN_MESSAGE_MAP(CMenuButton, CButton)
	ON_WM_DRAWITEM() 
	ON_WM_MEASUREITEM() 
	
	ON_WM_MOUSEMOVE() 
	ON_WM_LBUTTONUP() 
	ON_WM_LBUTTONDOWN()
	ON_WM_TIMER()
	ON_WM_KILLFOCUS() 
END_MESSAGE_MAP()



// CMenuButton message handlers


